@@ -82,13 +82,13 @@ class AgentManager : public QObject, protected QDBusContext
      * Returns the i18n'ed name of the agent type for
      * the given @p identifier and the given @p language.
      */
-    QString agentName( const QString &identifier, const QString &language = QString("en_US") ) const;
+    QString agentName( const QString &identifier, const QString &language = QLatin1String("en_US") ) const;
 
     /**
      * Returns the i18n'ed comment of the agent type for
      * the given @p identifier and the given @p language.
      */
-    QString agentComment( const QString &identifier, const QString &language = QString("en_US") ) const;
+    QString agentComment( const QString &identifier, const QString &language = QLatin1String("en_US") ) const;
 
     /**
      * Returns the icon name of the agent type for the
@@ -168,7 +168,7 @@ class AgentManager : public QObject, protected QDBusContext
      * If there is no name, it returns the default name of the agent, you can tweak
      * the language for that name with the @p language setting.
      */
-    QString agentInstanceName( const QString &identifier, const QString &language = QString( "en_US" ) ) const;
+    QString agentInstanceName( const QString &identifier, const QString &language = QLatin1String( "en_US" ) ) const;
 
     /**
      * Triggers the agent instance with the given @p identifier to show
