@@ -26,6 +26,7 @@
 #include "imapstreamparser.h"
 #include "nepomuksearch.h"
 #include "response.h"
+#include "xesamsearch.h"
 
 #include <QtCore/QStringList>
 
@@ -46,9 +47,15 @@ bool Search::parseStream()
   if ( queryString.isEmpty() )
     return failureResponse( "No query specified" );
 
+#ifdef AKONADI_USE_STRIGI_SEARCH
+  XesamSearch *service = new XesamSearch;
+  const QStringList uids = service->search( QString::fromUtf8( queryString ) );
+  delete service;
+#else
   NepomukSearch *service = new NepomukSearch;
   const QStringList uids = service->search( QString::fromUtf8( queryString ) );
   delete service;
+#endif
 
   if ( uids.isEmpty() ) {
     m_streamParser->readUntilCommandEnd(); // skip the fetch scope
@@ -56,7 +63,7 @@ bool Search::parseStream()
   }
 
   // create imap query
-  QList<ImapSet::Id> imapIds;
+  QVector<ImapSet::Id> imapIds;
   foreach ( const QString &uid, uids )
     imapIds.append( uid.toULongLong() );
 
@@ -69,8 +76,6 @@ bool Search::parseStream()
   fetchHelper.setStreamParser( m_streamParser );
   connect( &fetchHelper, SIGNAL( responseAvailable( const Response& ) ),
            this, SIGNAL( responseAvailable( const Response& ) ) );
-  connect( &fetchHelper, SIGNAL( failureResponse( const QString& ) ),
-           this, SLOT( slotFailureResponse( const QString& ) ) );
 
   if ( !fetchHelper.parseStream( "SEARCH" ) )
     return false;
@@ -79,9 +84,4 @@ bool Search::parseStream()
   return true;
 }
 
-void Search::slotFailureResponse( const QString &msg )
-{
-  failureResponse( msg );
-}
-
 #include "search.moc"
