@@ -70,6 +70,15 @@ void Akonadi::ResourceManager::removeResourceInstance(const QString & name)
   }
 }
 
+QStringList ResourceManager::resourceInstances() const
+{
+  QStringList result;
+  foreach ( const Resource &res, Resource::retrieveAll() )
+    result.append( res.name() );
+  return result;
+}
+
+
 ResourceManager * Akonadi::ResourceManager::self()
 {
   if ( !mSelf )
